@@ -9,7 +9,6 @@ from pathlib import Path
 
 import toml
 import typer
-import yaml
 
 # Import cloud helper lazily inside functions to avoid heavy deps at module load
 
@@ -112,6 +111,7 @@ def build_and_upload_wheel(bump_part: str = "patch"):
     print("Using UV_PUBLISH_TOKEN for authentication.")
 
     pyproject_path = "pyproject.toml"
+    mac_manifest_path = "pyproject.mac.toml"
     current_version = None  # Initialize in case the first try block fails
 
     try:
@@ -173,6 +173,25 @@ def build_and_upload_wheel(bump_part: str = "patch"):
         with open(pyproject_path, "w") as f:
             f.write(new_content)
         print(f"Updated {pyproject_path} with version {new_version}")
+
+        # Mirror version in pyproject.mac.toml if present (best-effort)
+        mac_updated = False
+        try:
+            mac_path = Path(mac_manifest_path)
+            if mac_path.exists():
+                mac_content = mac_path.read_text()
+                mac_pattern = re.compile(
+                    f'^version\s*=\s*"{re.escape(current_version)}"', re.MULTILINE
+                )
+                mac_new_content, mac_replacements = mac_pattern.subn(
+                    f'version = "{new_version}"', mac_content
+                )
+                if mac_replacements > 0:
+                    mac_path.write_text(mac_new_content)
+                    mac_updated = True
+                    print(f"Updated {mac_manifest_path} with version {new_version}")
+        except Exception as e:
+            print(f"Warning: Could not update {mac_manifest_path}: {e}")
         # --- End Version Bumping Logic ---
 
         # Build wheel and sdist
@@ -191,6 +210,27 @@ def build_and_upload_wheel(bump_part: str = "patch"):
 
         print(f"Successfully built and uploaded version {new_version} to PyPI")
 
+        # Re-install DHT in current venv when building from DHT itself
+        try:
+            proj_name = None
+            try:
+                proj_toml = toml.load(pyproject_path)
+                proj_name = (
+                    proj_toml.get("project", {}).get("name")
+                    if isinstance(proj_toml, dict)
+                    else None
+                )
+            except Exception:
+                pass
+            if proj_name == "dayhoff-tools":
+                print("Re-installing dayhoff-tools into the active environment…")
+                reinstall_cmd = ["uv", "pip", "install", "-e", ".[full]"]
+                print(f"Running command: {BLUE}{' '.join(reinstall_cmd)}{RESET}")
+                subprocess.run(reinstall_cmd, check=True)
+                print("dayhoff-tools reinstalled in the current environment.")
+        except subprocess.CalledProcessError as e:
+            print(f"Warning: Failed to reinstall dayhoff-tools locally: {e}")
+
     except FileNotFoundError:
         print(f"Error: {pyproject_path} not found.")
         # No version change happened, so no rollback needed
@@ -219,6 +259,24 @@ def build_and_upload_wheel(bump_part: str = "patch"):
                     print(
                         f"Warning: Could not find version {new_version} to revert in {pyproject_path}."
                     )
+
+                # Also revert mac manifest if we updated it
+                try:
+                    mac_path = Path(mac_manifest_path)
+                    if mac_path.exists():
+                        mac_content_revert = mac_path.read_text()
+                        mac_reverted, mac_num = pattern_revert.subn(
+                            f'version = "{current_version}"', mac_content_revert
+                        )
+                        if mac_num > 0:
+                            mac_path.write_text(mac_reverted)
+                            print(
+                                f"Successfully reverted version in {mac_manifest_path}."
+                            )
+                except Exception as e2:
+                    print(
+                        f"Warning: Failed to revert version change in {mac_manifest_path}: {e2}"
+                    )
             except Exception as revert_e:
                 print(
                     f"Warning: Failed to revert version change in {pyproject_path}: {revert_e}"
@@ -248,6 +306,23 @@ def build_and_upload_wheel(bump_part: str = "patch"):
                     print(
                         f"Warning: Could not find version {new_version} to revert in {pyproject_path}."
                     )
+                # Also revert mac manifest if necessary
+                try:
+                    mac_path = Path(mac_manifest_path)
+                    if mac_path.exists():
+                        mac_content_revert = mac_path.read_text()
+                        mac_reverted, mac_num = pattern_revert.subn(
+                            f'version = "{current_version}"', mac_content_revert
+                        )
+                        if mac_num > 0:
+                            mac_path.write_text(mac_reverted)
+                            print(
+                                f"Successfully reverted version in {mac_manifest_path}."
+                            )
+                except Exception as e2:
+                    print(
+                        f"Warning: Failed to revert version change in {mac_manifest_path}: {e2}"
+                    )
             except Exception as revert_e:
                 print(
                     f"Warning: Failed to revert version change in {pyproject_path}: {revert_e}"
@@ -265,42 +340,88 @@ def install_dependencies(
         help="Install the local project package itself (with 'full' extras) into the environment.",
     ),
 ):
-    """Install dependencies based on pyproject.toml.
+    """Install dependencies respecting Mac devcontainer flow and the active venv.
 
-    Ensures uv.lock matches pyproject.toml and syncs the environment.
-    When -p is used, installs the local project with its [full] optional dependencies.
+    Behavior:
+    - If running on Mac devcontainer (STUDIO_PLATFORM=mac) and `pyproject.mac.toml` exists:
+      * Ensure `.mac_uv_project/pyproject.toml` is a copy of `pyproject.mac.toml`
+      * Run `uv lock` and `uv sync` in `.mac_uv_project` and always target the active venv with `--active`
+      * If `install_project` is true, install the project from repo root into the active env (editable, [full])
+    - Otherwise (default path):
+      * Operate in repo root, ensure lock, and `uv sync --active` so we don't create `.venv` accidentally
+      * If `install_project` is true, sync without `--no-install-project` (installs project)
     """
     # ANSI color codes
     BLUE = "\033[94m"
     RESET = "\033[0m"
 
     try:
-        # Step 1: Ensure lock file matches pyproject.toml
-        print("Ensuring lock file matches pyproject.toml...")
-        lock_cmd = ["uv", "lock"]
-        print(f"Running command: {BLUE}{' '.join(lock_cmd)}{RESET}")
-        subprocess.run(lock_cmd, check=True, capture_output=True)
+        is_mac = os.environ.get("STUDIO_PLATFORM") == "mac"
+        mac_manifest = Path("pyproject.mac.toml")
+        if is_mac and mac_manifest.exists():
+            # Mac devcontainer flow
+            mac_uv_dir = Path(".mac_uv_project")
+            mac_uv_dir.mkdir(parents=True, exist_ok=True)
+            mac_pyproject = mac_uv_dir / "pyproject.toml"
+            mac_pyproject.write_text(mac_manifest.read_text())
 
-        if install_project:
-            # Step 2a: Install the project with 'full' extras
-            print("Installing the local project with 'full' extras...")
-            # The .[full] syntax tells pip to install the current project ('.')
-            # with its 'full' optional dependencies.
-            pip_install_cmd = ["uv", "pip", "install", "-e", ".[full]"]
-            print(f"Running command: {BLUE}{' '.join(pip_install_cmd)}{RESET}")
-            subprocess.run(pip_install_cmd, check=True)
-
-            print("Project installed with 'full' extras successfully.")
-        else:
-            # Original behavior: Sync environment without installing the project
-            print(
-                "Syncing environment with lock file (project itself will not be installed)..."
+            # Ensure lock matches manifest (in mac temp dir)
+            print("Ensuring lock file matches pyproject.mac.toml (Mac devcon)…")
+            lock_cmd = ["uv", "lock"]
+            print(f"Running command: {BLUE}{' '.join(lock_cmd)}{RESET}")
+            subprocess.run(
+                lock_cmd, check=True, capture_output=True, cwd=str(mac_uv_dir)
             )
-            # --all-groups ensures all non-project dependencies (like dev) are installed
-            sync_cmd = ["uv", "sync", "--all-groups", "--no-install-project"]
-            print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
-            subprocess.run(sync_cmd, check=True)
-            print("Dependencies synced successfully (project not installed).")
+
+            # Sync into the active environment
+            if install_project:
+                print(
+                    "Syncing dependencies into ACTIVE env and installing project [full]…"
+                )
+                sync_cmd = ["uv", "sync", "--all-groups", "--active"]
+                print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
+                subprocess.run(sync_cmd, check=True, cwd=str(mac_uv_dir))
+                # Install project from repo root
+                pip_install_cmd = ["uv", "pip", "install", "-e", ".[full]"]
+                print(f"Running command: {BLUE}{' '.join(pip_install_cmd)}{RESET}")
+                subprocess.run(pip_install_cmd, check=True)
+                print("Project installed with 'full' extras successfully.")
+            else:
+                print("Syncing dependencies into ACTIVE env (project not installed)…")
+                sync_cmd = [
+                    "uv",
+                    "sync",
+                    "--all-groups",
+                    "--no-install-project",
+                    "--active",
+                ]
+                print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
+                subprocess.run(sync_cmd, check=True, cwd=str(mac_uv_dir))
+                print("Dependencies synced successfully (project not installed).")
+        else:
+            # Default behavior in repo root, but ensure we target the active env
+            print("Ensuring lock file matches pyproject.toml…")
+            lock_cmd = ["uv", "lock"]
+            print(f"Running command: {BLUE}{' '.join(lock_cmd)}{RESET}")
+            subprocess.run(lock_cmd, check=True, capture_output=True)
+
+            if install_project:
+                print("Syncing dependencies into ACTIVE env (installing project)…")
+                sync_cmd = ["uv", "sync", "--all-groups", "--active"]
+                print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
+                subprocess.run(sync_cmd, check=True)
+            else:
+                print("Syncing dependencies into ACTIVE env (project not installed)…")
+                sync_cmd = [
+                    "uv",
+                    "sync",
+                    "--all-groups",
+                    "--no-install-project",
+                    "--active",
+                ]
+                print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
+                subprocess.run(sync_cmd, check=True)
+                print("Dependencies synced successfully (project not installed).")
 
     except subprocess.CalledProcessError as e:
         stderr_output = e.stderr.decode() if e.stderr else "No stderr output."
@@ -327,19 +448,27 @@ def update_dependencies(
         help="Update all dependencies instead of just dayhoff-tools.",
     ),
 ):
-    """Update dependencies to newer versions.
+    """Update dependencies to newer versions (Mac-aware, active venv friendly).
 
-    Default Action (no flags): Updates only 'dayhoff-tools' package to latest,
-                               updates pyproject.toml, and syncs.
+    - Default Action (no flags): Updates only 'dayhoff-tools' package to latest,
+      updates ALL manifest files with the version constraint, and syncs.
+    - Flags:
+      --all/-a: Updates all dependencies (uv lock --upgrade) and syncs.
 
-    Flags:
-    --all/-a: Updates all dependencies to latest compatible versions (`uv lock --upgrade`)
-              and syncs the environment. Overrides the default.
+    Cross-platform behavior:
+    - Always updates BOTH `pyproject.toml` and `pyproject.mac.toml` (if they exist)
+      to ensure version consistency across AWS and Mac platforms.
+    - On Mac: If STUDIO_PLATFORM=mac and `pyproject.mac.toml` exists, operates in
+      `.mac_uv_project/` and copies `pyproject.mac.toml` to `.mac_uv_project/pyproject.toml`.
+    - Always uses `--active` for sync to target the active venv.
     """
     # ANSI color codes
     BLUE = "\033[94m"
     RESET = "\033[0m"
 
+    is_mac = os.environ.get("STUDIO_PLATFORM") == "mac"
+    mac_manifest = Path("pyproject.mac.toml")
+    mac_uv_dir = Path(".mac_uv_project")
     lock_file_path = Path("uv.lock")
     pyproject_path = Path("pyproject.toml")
 
@@ -363,12 +492,21 @@ def update_dependencies(
         )
 
     try:
+        # Choose working directory for uv operations
+        uv_cwd = None
+        manifest_path_for_constraint = pyproject_path
+        if is_mac and mac_manifest.exists():
+            mac_uv_dir.mkdir(parents=True, exist_ok=True)
+            (mac_uv_dir / "pyproject.toml").write_text(mac_manifest.read_text())
+            uv_cwd = str(mac_uv_dir)
+            lock_file_path = mac_uv_dir / "uv.lock"
+            manifest_path_for_constraint = mac_manifest
         # Step 1: Run the update lock command
         print(action_description)
         print(f"Running command: {BLUE}{' '.join(lock_cmd)}{RESET}")
-        subprocess.run(lock_cmd, check=True, capture_output=True)
+        subprocess.run(lock_cmd, check=True, capture_output=True, cwd=uv_cwd)
 
-        # Step 2: Update pyproject.toml only if doing the dayhoff update (default)
+        # Step 2: Update both manifest files if doing the dayhoff update (default)
         if run_pyproject_update:
             print(f"Reading {lock_file_path} to find new dayhoff-tools version...")
             if not lock_file_path.exists():
@@ -395,59 +533,76 @@ def update_dependencies(
                 return
 
             print(f"Found dayhoff-tools version {locked_version} in lock file.")
-            print(f"Updating {pyproject_path} version constraint...")
-            try:
-                content = pyproject_path.read_text()
 
-                package_name = "dayhoff-tools"
-                package_name_esc = re.escape(package_name)
+            # Update both manifest files to ensure consistency across platforms
+            manifest_files_to_update = []
+            if pyproject_path.exists():
+                manifest_files_to_update.append(pyproject_path)
+            if mac_manifest.exists():
+                manifest_files_to_update.append(mac_manifest)
 
-                # Regex to match the dependency line, with optional extras and version spec
-                pattern = re.compile(
-                    rf"^(\s*['\"]){package_name_esc}(\[[^]]+\])?(?:[><=~^][^'\"]*)?(['\"].*)$",
-                    re.MULTILINE,
-                )
-
-                new_constraint_text = f">={locked_version}"
-
-                def _repl(match: re.Match):
-                    prefix = match.group(1)
-                    extras = match.group(2) or ""
-                    suffix = match.group(3)
-                    return (
-                        f"{prefix}{package_name}{extras}{new_constraint_text}{suffix}"
-                    )
-
-                new_content, num_replacements = pattern.subn(_repl, content)
-                if num_replacements > 0:
-                    pyproject_path.write_text(new_content)
-                    print(
-                        f"Updated dayhoff-tools constraint in {pyproject_path} to '{new_constraint_text}'"
-                    )
-                else:
-                    print(
-                        f"Warning: Could not find dayhoff-tools dependency line in {pyproject_path} to update constraint."
-                    )
-            except FileNotFoundError:
-                print(f"Error: {pyproject_path} not found.")
+            if not manifest_files_to_update:
+                print("Warning: No manifest files found to update.")
                 return
-            except Exception as e:
-                print(f"Error updating {pyproject_path}: {e}")
-                print("Proceeding with sync despite pyproject.toml update error.")
+
+            package_name = "dayhoff-tools"
+            package_name_esc = re.escape(package_name)
+
+            # Regex to match the dependency line, with optional extras and version spec
+            pattern = re.compile(
+                rf"^(\s*['\"]){package_name_esc}(\[[^]]+\])?(?:[><=~^][^'\"]*)?(['\"].*)$",
+                re.MULTILINE,
+            )
+
+            new_constraint_text = f">={locked_version}"
+
+            def _repl(match: re.Match):
+                prefix = match.group(1)
+                extras = match.group(2) or ""
+                suffix = match.group(3)
+                return f"{prefix}{package_name}{extras}{new_constraint_text}{suffix}"
+
+            # Update all manifest files
+            updated_files = []
+            for manifest_file in manifest_files_to_update:
+                try:
+                    print(f"Updating {manifest_file} version constraint...")
+                    content = manifest_file.read_text()
+                    new_content, num_replacements = pattern.subn(_repl, content)
+                    if num_replacements > 0:
+                        manifest_file.write_text(new_content)
+                        print(
+                            f"Updated dayhoff-tools constraint in {manifest_file} to '{new_constraint_text}'"
+                        )
+                        updated_files.append(str(manifest_file))
+                    else:
+                        print(
+                            f"Warning: Could not find dayhoff-tools dependency line in {manifest_file}"
+                        )
+                except FileNotFoundError:
+                    print(f"Warning: {manifest_file} not found.")
+                except Exception as e:
+                    print(f"Error updating {manifest_file}: {e}")
+
+            if not updated_files:
+                print(
+                    "Warning: No manifest files were successfully updated with dayhoff-tools constraint."
+                )
+                print("Proceeding with sync despite manifest update failures.")
 
         # Step 3: Sync environment
         print("Syncing environment with updated lock file...")
         # Always use --no-install-project for updates
-        sync_cmd = ["uv", "sync", "--all-groups", "--no-install-project"]
+        sync_cmd = ["uv", "sync", "--all-groups", "--no-install-project", "--active"]
         print(f"Running command: {BLUE}{' '.join(sync_cmd)}{RESET}")
-        subprocess.run(sync_cmd, check=True)
+        subprocess.run(sync_cmd, check=True, cwd=uv_cwd)
 
         # Final status message
         if update_all:
             print("All dependencies updated and environment synced successfully.")
         else:  # Default case (dayhoff update)
             print(
-                "dayhoff-tools updated, pyproject.toml modified, and environment synced successfully."
+                "dayhoff-tools updated, manifest files modified, and environment synced successfully."
             )
 
     except subprocess.CalledProcessError as e:
